<?php

/**
 * Queue some JavaScript code to be output in the footer.
 *
 * @param string $code
 */
function wpa_enqueue_js( $code ) {
    global $wpa_queued_js;

    if ( empty( $wpa_queued_js ) ) {
        $wpa_queued_js = '';
    }

    $wpa_queued_js .= "\n" . $code . "\n";
}

/**
 * Output any queued javascript code in the footer.
 */
function wpa_print_js() {
    global $wpa_queued_js;

    if ( ! empty( $wpa_queued_js ) ) {

        echo "<!-- Analytify footer JavaScript -->\n<script type=\"text/javascript\">\njQuery(function($) {";

        // Sanitize
        $wpa_queued_js = wp_check_invalid_utf8( $wpa_queued_js );
        $wpa_queued_js = preg_replace( '/&#(x)?0*(?(1)27|39);?/i', "'", $wpa_queued_js );
        $wpa_queued_js = str_replace( "\r", '', $wpa_queued_js );

        echo $wpa_queued_js . "});\n</script>\n";

        unset( $wpa_queued_js );
    }
}

/**
 * Change the admin footer text on Analytify admin pages
 *
 * @since  1.2.4
 * @param  string $footer_text
 * @return string
 */
function wpa_admin_rate_footer_text( $footer_text ) {

    $rate_text = '';
    $current_screen = get_current_screen();

    // Add the Analytify admin pages
    $wpa_pages[] = 'toplevel_page_analytify-dashboard';
    $wpa_pages[] = 'analytify_page_analytify-campaigns';
    $wpa_pages[] = 'analytify_page_analytify-settings';

    //update_option( 'analytify_admin_footer_text_rated', 0 );

    // Check to make sure we're on a Analytify admin pages
    if ( isset( $current_screen->id ) && in_array( $current_screen->id, $wpa_pages ) ) {
        // Change the footer text
        if ( ! get_option( 'analytify_admin_footer_text_rated' ) ) {
                $rate_text = sprintf( esc_html__( 'If you like %1$s Analytify %2$s please leave us a %5$s %3$s %6$s rating. %4$s A huge thank you from %1$s WPBrigade %2$s in advance!', 'wp-analytify' ), '<strong>', '</strong>', '&#9733;&#9733;&#9733;&#9733;&#9733;', '<br />', '<a href="https://wordpress.org/support/view/plugin-reviews/wp-analytify?filter=5#postform" target="_blank" class="wpa-rating-footer" data-rated="Thanks dude ;)">', '</a>' );
                    wpa_enqueue_js( "
                        jQuery('a.wpa-rating-footer').click(function() {
                            jQuery.post( '" . admin_url( 'admin-ajax.php') . "', { action: 'analytify_rated' } );
                            jQuery(this).parent().text( jQuery(this).data( 'rated' ) );
                        });
                    " );
        } else {
            $rate_text = esc_html_e( 'Thank you for tracking with Analytify.', 'wp-analytify' );
        }

        return $rate_text;
    }

    return $footer_text;
}

/**
 * Delete the cache of dashboard sections
 *
 * @since  1.2.6
 * @param  $start_date Start Date
 * @param  $end_date End Date
 * @return void
 */

function delete_dashboard_transients( $start_date, $end_date ) {

    delete_transient( md5('show-overall-dashboard'      . $start_date . $end_date ));
    delete_transient( md5('show-top-pages-dashboard'    . $start_date . $end_date ));
    delete_transient( md5('show-country-dashboard'      . $start_date . $end_date ));
    delete_transient( md5('show-city-dashboard'         . $start_date . $end_date ));
    delete_transient( md5('show-keywords-dashboard'     . $start_date . $end_date ));
    delete_transient( md5('show-social-dashboard'       . $start_date . $end_date ));
    delete_transient( md5('show-browser-dashboard'      . $start_date . $end_date ));
    delete_transient( md5('show-os-dashboard'           . $start_date . $end_date ));
    delete_transient( md5('show-mobile-dashboard'       . $start_date . $end_date ));
    delete_transient( md5('show-referrer-dashboard'     . $start_date . $end_date ));
    delete_transient( md5('show-page-stats-dashboard'   . $start_date . $end_date ));

}


/**
 * Dashboard settings backward compatibility till 1.2.5
 * @since 1.2.6
 *
 */
function wpa_dashboard_compatible(){
 
    $version = get_option( 'wpa_current_version' );

    if( !$version ) {
        // Run when version is less or equal than 1.2.5
        update_option( 'access_role_dashboard', array(
            'administrator',
            'editor'
            ));
        update_option( 'dashboard_panels',  array(
            'show-real-time',
            'show-overall-dashboard',
            'show-top-pages-dashboard',
            'show-os-dashboard',
            'show-country-dashboard',
            'show-keywords-dashboard',
            'show-social-dashboard',
            'show-browser-dashboard',
            'show-referrer-dashboard',
            'show-page-stats-dashboard',
            'show-mobile-dashboard',
            'show-os-dashboard',
            'show-city-dashboard'
            ));

        update_option('wpa_current_version', ANALYTIFY_VERSION);

    }

}


class WP_ANALYTIFY_FUNCTIONS {


    /**
     * @param  [string] page name
     * @param  string custom message
     * @return [boolean] true or false
     *
     * @since  [1.3]
     */
    public static function wpa_check_profile_selection( $type , $message = '') {

        if(! get_option( "pt_webprofile" )) {

            if($message == '')
                echo sprintf(esc_html__( '%1$s %2$s' . $type . ' Dashboard can\'t be loaded until your select your website profile %3$s here %4$s %5$s %6$s', 'wp-analytify'), '<div class="error notice is-dismissible">', '<p>', '<a style="text-decoration:none" href="' . menu_page_url ( 'analytify-settings', false ) . '&tab=profile">', '</a>', '</p>', '</div>');
            else
                echo $message;

            return true;
        }else{
            return false;
        }

    }


}

//delete_option( 'wpa_current_version' );
wpa_dashboard_compatible();